/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.taglib.logic;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspException;

import org.apache.struts.taglib.logic.RedirectTag;
import org.apache.struts.util.RequestUtils;
import org.hdiv.taglib.util.RequestUtilsHDIV;

/**
 * Generate a URL-encoded redirect to the specified URI.
 * 
 * @author Gorka Vicente
 * @see org.apache.struts.taglib.logic.RedirectTag
 */
public class RedirectTagHDIV extends RedirectTag {

	/**
	 * Universal version identifier. Deserialization uses this number to ensure that
	 * a loaded class corresponds exactly to a serialized object.
	 */
	private static final long serialVersionUID = -4137682108801542858L;

	/**
	 * Render the redirect and skip the remainder of this page.
	 * 
	 * @exception JspException if a JSP exception has occurred
	 */
	public int doEndTag() throws JspException {

		// calculate the url to redirect to
		String url = this.generateRedirectURL();

		// generate a new encoded values for the url parameters
		HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();

		String encodedURL = RequestUtilsHDIV.encodeURLParameters(request, url, "UTF-8");

		String urlHDIVstate = RequestUtilsHDIV.addHDIVState(encodedURL, this.getAnchor());

		// redirect to the given url
		this.doRedirect(urlHDIVstate);

		return (SKIP_PAGE);
	}

	/**
	 * Calculate the url to redirect to.
	 * 
	 * @throws JspException
	 */
	protected String generateRedirectURL() throws JspException {

		Map params = RequestUtils.computeParameters(pageContext, paramId, paramName, paramProperty,
													paramScope, name, property, scope, transaction);

		String url = null;
		try {
			url = RequestUtils.computeURL(pageContext, forward, href, page, params, anchor, true);
		} catch (MalformedURLException e) {
			RequestUtils.saveException(pageContext, e);
			throw new JspException(messages.getMessage("redirect.url", e.toString()));
		}

		return url;
	}

	/**
	 * Redirect to the given url converting exceptions to JspException.
	 * 
	 * @param url The path to redirect to.
	 * @throws JspException
	 */
	protected void doRedirect(String url) throws JspException {

		HttpServletResponse response = (HttpServletResponse) pageContext.getResponse();

		try {
			response.sendRedirect(url);

		} catch (IOException e) {
			RequestUtils.saveException(pageContext, e);
			throw new JspException(e.getMessage());
		}
	}

}
